// Copyright (c) 2022 Marceline Cramer
// SPDX-License-Identifier: AGPL-3.0-or-later

use glium::glutin::event_loop::EventLoopBuilder;

use canary_magpie::service::*;
use ipc::Ipc;
use window::{WindowMessage, WindowStore};

fn main() -> std::io::Result<()> {
    env_logger::Builder::new()
        .filter(None, log::LevelFilter::Info) // By default logs all info messages.
        .parse_default_env()
        .init();

    log::info!("Initializing Magpie...");
    let event_loop = EventLoopBuilder::<WindowMessage>::with_user_event().build();
    let window_sender = event_loop.create_proxy();
    let (ipc, ipc_sender) = Ipc::new(window_sender)?;
    let _ipc_thread = std::thread::spawn(|| ipc.run());
    let window_store = WindowStore::new(ipc_sender);
    window_store.run(event_loop)
}
